@@ -32,11 +32,6 @@ my $GCCP; # 'g++' or 'gcc': C/C++ preproc with `-E -MG' switches
 $GCCP="@ARGV";
 $GCCP="gcc" if $GCCP!~y/ \t//c;
 
-# Make sure we get English error messages from gcc.
-delete $ENV{LANG};
-delete $ENV{LANGUAGE};
-$ENV{LC_ALL} = "C";
-
 # ---
 
 sub find_ds() {
@@ -137,20 +132,13 @@ sub backtick(@) {
 
 my @DS=find_ds();
 my @DSQ=map{shq$_}@DS;
-my $DIAG=" -fno-diagnostics-show-caret";
-my $Q="$GCCP -DOBJDEP$DIAG -M -MG -E 2>&1 @DSQ";
-my $R=backtick($Q);
-if ($R=~/\berror: .*-fno-diagnostics-show-caret\b/) {
-  # gcc-4.6 and earlier don't have this flag, and they fail.
-  $Q=~s@ -fno-diagnostics-show-caret(?=\s)@@;
-  $DIAG="";
-  $R=backtick($Q);
-}
+my $R="$GCCP -DOBJDEP -M -MG -E 2>&1 @DSQ";
+$R=backtick($R);
 
 if ($R!~/: warning: #warning\b/) {
   # config2.h:314:4: warning: #warning REQUIRES: c_lgcc3.o
   # Dat: g++-3.3 ignores #warning with -M -MG -E
-  $R.="\n".backtick("$GCCP -DOBJDEP$DIAG -E 2>&1 >/dev/null @DSQ");
+  $R.="\n".backtick("$GCCP -DOBJDEP -E 2>&1 >/dev/null @DSQ");
 }
 
 ## die $R;
@@ -233,13 +221,10 @@ while ($R=~/\G(.*)\n?/g) {
   } elsif ($S=~/\A([^:]+):\d+:(\d+:)? warning: this is the location of /) {
     # ^^^ gcc-3.1
     undef $included_from;
-  } elsif ($S=~/: No such file or directory$/) {  # Depends on $ENV{LC_ALL}.
+  } elsif ($S=~/: No such file or directory$/) {
     # ^^^ gcc-3.3
     undef $included_from;
-  } elsif ($S eq 'compilation terminated.') {  # Useless message, ignore.
-  } elsif ($S=~/^distcc\[/) {  # Useless message, ignore.
-  } elsif ($S=~/^ *#/) {  # Useless message from gcc 4.8, ignore.
-  } elsif ($S=~/^ *\^/) {  # Useless message from gcc 4.8, ignore.
+  } elsif ($S=~/^distcc\[/) {
   } else {
     die "$0: invalid depret: [$S]\n";
   }
